| Name                                    |   Stmts |   Miss |  Branch | BrPart |   Cover |
| --------------------------------------- | ------: | -----: | ------: | -----: | ------: |
| src/hatch_cythonize/\_\_init\_\_.py        |       2 |      0 |       0 |      0 |    100% |
| src/hatch_cythonize/config/\_\_init\_\_.py |       2 |      0 |       0 |      0 |    100% |
| src/hatch_cythonize/config/autoimport.py   |       9 |      0 |       2 |      0 |    100% |
| src/hatch_cythonize/config/config.py       |     143 |      9 |      60 |      6 |     92% |
| src/hatch_cythonize/config/defaults.py     |      27 |      0 |       8 |      1 |     97% |
| src/hatch_cythonize/config/files.py        |      35 |      0 |      16 |      1 |     98% |
| src/hatch_cythonize/config/flags.py        |      69 |      1 |      24 |      0 |     99% |
| src/hatch_cythonize/config/includes.py     |      15 |      0 |       8 |      0 |    100% |
| src/hatch_cythonize/config/macros.py       |      12 |      0 |       7 |      0 |    100% |
| src/hatch_cythonize/config/platform.py     |      75 |      0 |      30 |      3 |     97% |
| src/hatch_cythonize/config/templates.py    |      62 |      5 |      32 |      4 |     90% |
| src/hatch_cythonize/constants.py           |      15 |      0 |       0 |      0 |    100% |
| src/hatch_cythonize/devel.py               |       5 |      0 |       0 |      0 |    100% |
| src/hatch_cythonize/hooks.py               |       5 |      1 |       2 |      0 |     86% |
| src/hatch_cythonize/plugin.py              |     248 |     12 |     156 |     10 |     95% |
| src/hatch_cythonize/temp.py                |      13 |      0 |       2 |      0 |    100% |
| src/hatch_cythonize/utils.py               |      39 |      0 |      16 |      0 |    100% |
| **TOTAL**                               | **776** | **28** | **363** | **25** | **95%** |
